variable "sqs_queue_name" {
  type        = string
  description = "Name of the SQS Queue"
}

variable "dlq_name" {
  type        = string
  description = "Name of the DLQ SQS Queue"
}

variable "visibility_timeout_seconds" {
  type        = number
  default     = 30
  description = "The visibility timeout for the queue"
}

variable "delay_seconds" {
  type        = number
  default     = 0
  description = "The time in seconds that the delivery of all messages in the queue will be delayed"
}

variable "max_message_size" {
  type        = number
  default     = 262144
  description = "The limit of how many bytes a message can contain before Amazon SQS rejects it"
}

variable "message_retention_seconds" {
  type        = number
  default     = 86400
  description = "The number of seconds Amazon SQS retains a message"
}

variable "receive_wait_time_seconds" {
  type        = number
  default     = 0
  description = "The time for which a ReceiveMessage call will wait for a message to arrive (long polling) before returning"
}

variable "max_receive_count" {
  type        = number
  default     = 4
  description = "The time for which a ReceiveMessage call will wait for a message to arrive (long polling) before returning"
}
variable "allowed_aws_services_for_sqs_send_message" {
  type        = string
  default     = ""
  description = "Services that need access to send messages to the SQS queue"
}

variable "fifo_queue" {
  type        = bool
  default     = false
  description = "Boolean designating a FIFO queue"
}

variable "use_sqs_as_dlq" {
  type        = bool
  default     = false
  description = "Is the queue being used as DLQ for another resource like lambda"
}

variable "content_based_deduplication" {
  type        = bool
  default     = false
  description = "Enables content-based deduplication for FIFO queues"
}

variable "kms_master_key_id" {
  type        = string
  default     = "alias/mcs2-carbonblack"
  description = "Kms key id for encryption"
}

variable "kms_data_key_reuse_period_seconds" {
  type        = number
  default     = 300
  description = "The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling AWS KMS again"
}

variable "tags" {
  type        = map(string)
  description = "Tags for SQS Queue"
}

variable "iam_policy_prefix" {
  type = string
}

variable "enable_iam_policies" {
  type    = bool
  default = true
}